import { connect, Dispatch } from 'react-redux';
import {
  SignIn,
  StateProps as SignInStateProps,
  DispatchProps as SigninDispatchProps,
  Props as SignInProps,
} from './components/SignIn';
import SignInState from '../redux/state/SignIn';

import * as signinActions from '../redux/action/signIn';
import * as forgotPasswordAction from '../redux/action/forgot_password';

import { push as routerPush } from 'react-router-redux';
import * as asyncRequestActions from '@overflow/commons/redux/action/asyncRequest';
import * as asyncRestRequestAction from '@overflow/commons/redux/action/asyncRestRequest';

export function mapStateToProps(state: SignInState, ownProps?: SignInStateProps): SignInStateProps {
  console.log(state.error);
  return {
    isAuthenticated: state.isAuthenticated,
    error:state.error,
  };
}

export function mapDispatchToProps(dispatch: Dispatch<any>, ownProps?: any): SigninDispatchProps {
  return {
    onSignIn: (signinId: string, signinPw: string) => {
      // dispatch(signinActions.request(signinId, signinPw));
      dispatch(asyncRequestActions.request('MemberService', 'signin', signinActions.REQUEST, signinId, signinPw));
    },
    onRedirectHome: () => {
      dispatch(routerPush('/'));
    },
    onForgotPassword: (email:string) => {
      dispatch(asyncRestRequestAction.request('/forgot_password', 'POST', forgotPasswordAction.REQUEST, {signinId:email}));
    },
  };
}

export default connect(mapStateToProps, mapDispatchToProps)(SignIn);
